# Better Day 🌞
Need help? Join our Discord community: https://discord.gg/qgnR8CCRE3

### Installation 🛠️
Notice: You are on the stable branch
This means that you will only receive thoroughly tested updates. For the latest features and updates, switch to the Unstable Branch. Thank you.

To ensure the script and update scripts work correctly, you must be logged in to git and gh. We do not store any credentials; they are solely for Git usage.

### Linux / Windows installation:









```
git clone https://github.com/tytan-codes/better-day.git
cd better-day
python3 -m pip install -r requirements.txt
python3 main.py
```
#Usage 🚀
List all arguments:

```
python3 main.py -h
```
Start the Windows version (not required as of update 4.5.3):

```
python3 main.py --Windows
```
Start the Linux version (not required as of update 4.5.3):

```
python3 main.py --Linux
```
### DEMO:


https://user-images.githubusercontent.com/91703892/235813569-0d43b29d-2284-4bb5-8350-ac6d118b7c22.mp4



### Note 📝
This script is protected under the Attribution-NonCommercial-NoDerivatives 4.0 International (CC BY-NC-ND 4.0) license.

- [x] Added at least 12 working functions
- [x] Improved CLI ease of use
- [x] Made CLI look AWESOME
- [x] Cross-platform compatibility (Linux / Windows)
- [ ] Add UI
- [ ] Ensure compatibility with macOS
Created by Tytan. Enjoy Better Day! 🎉
